Learn R Programming

theft (version 0.8.2)

moments: Calculate a basic set of the four moments of the distribution

Description

Calculate a basic set of the four moments of the distribution

Usage

moments(y)

Value

data.frame of results

Arguments

y

numeric vector of values

Author

Trent Henderson